client

package
v0.0.0-...-6091764 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2019 License: Apache-2.0 Imports: 11 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client interface {
	Request(interface{}) (*http.Response, error)
	StreamID() string
	SetStreamID(string) Client
}

func NewClient

func NewClient(data ClientData, logger logging.Logger) Client

Return a new HTTP client.

type ClientData

type ClientData struct {
	Endpoint string
	Auth     string
}

type DefaultClient

type DefaultClient struct {
	// contains filtered or unexported fields
}

HTTP client.

func (*DefaultClient) Request

func (c *DefaultClient) Request(call interface{}) (*http.Response, error)

Makes a new request with data and sends it to the server. Determines whether the request/response should be handled for an executor or a scheduler.

func (*DefaultClient) SetStreamID

func (c *DefaultClient) SetStreamID(id string) Client

Sets our stream ID.

func (*DefaultClient) StreamID

func (c *DefaultClient) StreamID() string

Gets our stream ID.

Jump to