utils

package
v0.0.0-...-6091764 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2019 License: Apache-2.0 Imports: 4 Imported by: 2

Documentation

Index

Constants

const (
	IPV4FIRSTBIT = 10
	IPv4Bits     = 32
)

Variables

This section is empty.

Functions

func GetInternalNetworkInterface

func GetInternalNetworkInterface(subnet int) (net.IP, error)

Gathers the internal network as defined. This will not work if there are multiple 10.0.0.0/24's on a host. NOTE (tim): Talk to mike c about how the new /25 networks will work, as well as overlay networks.

func ProtoBool

func ProtoBool(i bool) *bool

func ProtoFloat64

func ProtoFloat64(f float64) *float64

func ProtoInt32

func ProtoInt32(i int32) *int32

func ProtoInt64

func ProtoInt64(i int64) *int64

func ProtoString

func ProtoString(s string) *string

func ProtoUint32

func ProtoUint32(i uint32) *uint32

func Uuid

func Uuid() []byte

Generates a UUID using random bytes from a secure source.

func UuidAsString

func UuidAsString() string

Types

This section is empty.

Jump to