Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type ClientData ¶
type DefaultClient ¶
type DefaultClient struct {
// contains filtered or unexported fields
}
HTTP client.
func (*DefaultClient) Request ¶
func (c *DefaultClient) Request(call interface{}) (*http.Response, error)
Makes a new request with data and sends it to the server. Determines whether the request/response should be handled for an executor or a scheduler.
func (*DefaultClient) SetStreamID ¶
func (c *DefaultClient) SetStreamID(id string) Client
Sets our stream ID.
Click to show internal directories.
Click to hide internal directories.