Documentation
¶
Index ¶
- Constants
- func GetInternalNetworkInterface(subnet int) (net.IP, error)
- func ProtoBool(i bool) *bool
- func ProtoFloat64(f float64) *float64
- func ProtoInt32(i int32) *int32
- func ProtoInt64(i int64) *int64
- func ProtoString(s string) *string
- func ProtoUint32(i uint32) *uint32
- func Uuid() []byte
- func UuidAsString() string
Constants ¶
const ( IPV4FIRSTBIT = 10 IPv4Bits = 32 )
Variables ¶
This section is empty.
Functions ¶
func GetInternalNetworkInterface ¶
Gathers the internal network as defined. This will not work if there are multiple 10.0.0.0/24's on a host. NOTE (tim): Talk to mike c about how the new /25 networks will work, as well as overlay networks.
func ProtoFloat64 ¶
func ProtoInt32 ¶
func ProtoInt64 ¶
func ProtoString ¶
func ProtoUint32 ¶
func UuidAsString ¶
func UuidAsString() string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.